/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-
 *
 * tracker-tag-cloud-model.h: Model for the TrackerTagCloud widget
 *
 * Copyright (C) 2007 Marko Anastasov <marko@marko.anastasov.name>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 */

#ifndef __TRACKER_TAG_CLOUD_MODEL_H__
#define __TRACKER_TAG_CLOUD_MODEL_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>

G_BEGIN_DECLS

#define TYPE_TRACKER_TAG_CLOUD_MODEL            (tracker_tag_cloud_model_get_type ())
#define TRACKER_TAG_CLOUD_MODEL(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TRACKER_TAG_CLOUD_MODEL, TrackerTagCloudModel))
#define TRACKER_TAG_CLOUD_MODEL_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TRACKER_TAG_CLOUD_MODEL, TrackerTagCloudModelClass))
#define TRACKER_IS_TAG_CLOUD_MODEL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TRACKER_TAG_CLOUD_MODEL))
#define TRACKER_IS_TAG_CLOUD_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TRACKER_TAG_CLOUD_MODEL))
#define TRACKER_TAG_CLOUD_MODEL_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TRACKER_TAG_CLOUD_MODEL, TrackerTagCloudModelClass))

typedef struct _TrackerTagCloudModel TrackerTagCloudModel;
typedef struct _TrackerTagCloudModelClass TrackerTagCloudModelClass;
typedef struct _TrackerTagCloudModelPrivate TrackerTagCloudModelPrivate;

struct _TrackerTagCloudModel
{
	GObject parent;

	TrackerTagCloudModelPrivate *priv;
};

struct _TrackerTagCloudModelClass
{
	GObjectClass parent;

	/* Signals */
	void (* changed) (TrackerTagCloudModel *model);

	/* Padding for future expansion */
	void (*_tracker_tag_cloud_model_reserved1) (void);
	void (*_tracker_tag_cloud_model_reserved2) (void);
	void (*_tracker_tag_cloud_model_reserved3) (void);
	void (*_tracker_tag_cloud_model_reserved4) (void);
	void (*_tracker_tag_cloud_model_reserved5) (void);
	void (*_tracker_tag_cloud_model_reserved6) (void);
	void (*_tracker_tag_cloud_model_reserved7) (void);
};

TrackerTagCloudModel * tracker_tag_cloud_model_new               (gint min_font_size,
								  gint max_font_size);

void                   tracker_tag_cloud_model_add_tag           (TrackerTagCloudModel* model,
								  const gchar* tag);

GHashTable *           tracker_tag_cloud_model_get_font_sizes    (TrackerTagCloudModel* model);

gint                   tracker_tag_cloud_model_get_min_font_size (TrackerTagCloudModel* model);
void                   tracker_tag_cloud_model_set_min_font_size (TrackerTagCloudModel* model,
								  gint value);

gint                   tracker_tag_cloud_model_get_max_font_size (TrackerTagCloudModel* model);
void                   tracker_tag_cloud_model_set_max_font_size (TrackerTagCloudModel* model,
								  gint value);

GType                  tracker_tag_cloud_model_get_type          (void);

G_END_DECLS

#endif /* __TRACKER_TRACKER_TAG_CLOUD_MODEL_H__ */
